# Copyright 2025 Softwell S.r.l. - SPDX-License-Identifier: Apache-2.0

"""ChefApp - Didactic example of a builder-based application."""

from .chef_app import ChefApp
from .menu_builder import MenuBuilder

__all__ = ["ChefApp", "MenuBuilder"]
